@@ -2,7 +2,7 @@
 #'
 #' @description Coefficient of variation radius of gyration (Area and edge metric)
 #'
-#' @param landscape Raster* Layer, Stack, Brick or a list of rasterLayers.
+#' @param landscape Raster* Layer, Stack, Brick, SpatRaster (terra), stars, or a list of rasterLayers.
 #' @param directions The number of directions in which patches should be
 #' connected: 4 (rook's case) or 8 (queen's case).
 #' @param cell_center If true, the coordinates of the centroid are forced to be
@@ -56,86 +56,9 @@
 #' in fragmented landscapes. Conservation ecology, 1(1).
 #'
 #' @export
-lsm_c_gyrate_cv <- function(landscape, directions, cell_center) UseMethod("lsm_c_gyrate_cv")
-
-#' @name lsm_c_gyrate_cv
-#' @export
-lsm_c_gyrate_cv.RasterLayer <- function(landscape,
-                                        directions = 8, cell_center = FALSE) {
-
-    result <- lapply(X = raster::as.list(landscape),
-                     FUN = lsm_c_gyrate_cv_calc,
-                     directions = directions,
-                     cell_center = cell_center)
-
-    layer <- rep(seq_along(result),
-                 vapply(result, nrow, FUN.VALUE = integer(1)))
-
-    result <- do.call(rbind, result)
-
-    tibble::add_column(result, layer, .before = TRUE)
-}
-
-#' @name lsm_c_gyrate_cv
-#' @export
-lsm_c_gyrate_cv.RasterStack <- function(landscape,
-                                        directions = 8, cell_center = FALSE) {
-
-    result <- lapply(X = raster::as.list(landscape),
-                     FUN = lsm_c_gyrate_cv_calc,
-                     directions = directions,
-                     cell_center = cell_center)
-
-    layer <- rep(seq_along(result),
-                 vapply(result, nrow, FUN.VALUE = integer(1)))
-
-    result <- do.call(rbind, result)
-
-    tibble::add_column(result, layer, .before = TRUE)
-}
-
-#' @name lsm_c_gyrate_cv
-#' @export
-lsm_c_gyrate_cv.RasterBrick <- function(landscape,
-                                        directions = 8, cell_center = FALSE) {
-
-    result <- lapply(X = raster::as.list(landscape),
-                     FUN = lsm_c_gyrate_cv_calc,
-                     directions = directions,
-                     cell_center = cell_center)
-
-    layer <- rep(seq_along(result),
-                 vapply(result, nrow, FUN.VALUE = integer(1)))
-
-    result <- do.call(rbind, result)
-
-    tibble::add_column(result, layer, .before = TRUE)
-}
-
-#' @name lsm_c_gyrate_cv
-#' @export
-lsm_c_gyrate_cv.stars <- function(landscape,
-                                  directions = 8, cell_center = FALSE) {
-
-    landscape <- methods::as(landscape, "Raster")
-
-    result <- lapply(X = raster::as.list(landscape),
-                     FUN = lsm_c_gyrate_cv_calc,
-                     directions = directions,
-                     cell_center = cell_center)
-
-    layer <- rep(seq_along(result),
-                 vapply(result, nrow, FUN.VALUE = integer(1)))
-
-    result <- do.call(rbind, result)
-
-    tibble::add_column(result, layer, .before = TRUE)
-}
-
-#' @name lsm_c_gyrate_cv
-#' @export
-lsm_c_gyrate_cv.list <- function(landscape,
+lsm_c_gyrate_cv <- function(landscape,
                                  directions = 8, cell_center = FALSE) {
+    landscape <- landscape_as_list(landscape)
 
     result <- lapply(X = landscape,
                      FUN = lsm_c_gyrate_cv_calc,
