@@ -68,16 +68,15 @@ lsm_c_np_calc <- function(landscape, directions){
     }
 
     # get unique classes
-    classes <- get_unique_values(landscape)[[1]]
+    classes <- get_unique_values_int(landscape, verbose = FALSE)
 
     # get number of patches
     return(do.call(rbind, lapply(X = classes, FUN = function(patches_class) {
 
         # connected labeling current class
-        landscape_labeled <- get_patches(landscape,
-                                         class = patches_class,
-                                         directions = directions,
-                                         return_raster = FALSE)[[1]]
+        landscape_labeled <- get_patches_int(landscape,
+                                             class = patches_class,
+                                             directions = directions)[[1]]
 
         # max(patch_id) equals number of patches
         np <- max(landscape_labeled, na.rm = TRUE)
