@@ -81,9 +81,9 @@ lsm_c_te_calc <- function(landscape, count_boundary, directions, resolution = NU
     resolution_y <- resolution[[2]]
 
     # get class id
-    classes <- get_unique_values(landscape)[[1]]
+    classes <- get_unique_values_int(landscape, verbose = FALSE)
 
-    if(length(classes) == 1 && !count_boundary) {
+    if (length(classes) == 1 && !count_boundary) {
 
         tibble::tibble(
             level = "class",
@@ -96,7 +96,7 @@ lsm_c_te_calc <- function(landscape, count_boundary, directions, resolution = NU
     else {
 
         # resolution not identical in x and y direction
-        if(resolution_x != resolution_y){
+        if (resolution_x != resolution_y) {
 
             top_bottom_matrix <- matrix(c(NA, NA, NA,
                                           1,  0, 1,
@@ -110,10 +110,9 @@ lsm_c_te_calc <- function(landscape, count_boundary, directions, resolution = NU
         return(do.call(rbind, lapply(X = classes, FUN = function(patches_class) {
 
             # get connected patches
-            landscape_labeled <- get_patches(landscape,
-                                             class = patches_class,
-                                             directions = directions,
-                                             return_raster = FALSE)[[1]]
+            landscape_labeled <- get_patches_int(landscape,
+                                                 class = patches_class,
+                                                 directions = directions)[[1]]
 
             # set all non-class patches, but not NAs, to -999
             edge_cells <- which(!is.na(landscape) & landscape != patches_class)
@@ -122,10 +121,10 @@ lsm_c_te_calc <- function(landscape, count_boundary, directions, resolution = NU
 
             # add one row/coloumn to count landscape boundary
             if (count_boundary) {
-                landscape_labeled <- pad_raster(landscape = landscape_labeled,
-                                                pad_raster_value = -999,
-                                                pad_raster_cells = 1,
-                                                return_raster = FALSE)[[1]]
+                landscape_labeled <- pad_raster_internal(landscape = landscape_labeled,
+                                                         pad_raster_value = -999,
+                                                         pad_raster_cells = 1,
+                                                         global = FALSE)
 
                 # set NA to -999
                 landscape_labeled[is.na(landscape_labeled)] <- -999
