@@ -77,198 +77,6 @@
 #'
 #' @export
 sample_lsm <- function(landscape,
-                       y,
-                       plot_id,
-                       shape, size,
-                       all_classes,
-                       return_raster,
-                       verbose,
-                       progress,
-                       ...) UseMethod("sample_lsm")
-
-#' @name sample_lsm
-#' @export
-sample_lsm.RasterLayer <- function(landscape,
-                                   y,
-                                   plot_id = NULL,
-                                   shape = "square", size,
-                                   all_classes = FALSE,
-                                   return_raster = FALSE,
-                                   verbose = TRUE,
-                                   progress = FALSE,
-                                   ...) {
-
-    result <- lapply(X = raster::as.list(landscape),
-                     FUN = sample_lsm_int,
-                     y = y,
-                     plot_id = plot_id,
-                     shape = shape, size = size,
-                     all_classes = all_classes,
-                     verbose = verbose,
-                     progress = progress,
-                     ...)
-
-    layer <- rep(seq_len(length(result)),
-                 vapply(result, nrow, FUN.VALUE = integer(1)))
-
-    result <- do.call(rbind, result)
-
-    result$layer <- layer
-
-    if (!return_raster) {
-        result  <- result[, -9]
-    }
-
-    result[with(result, order(layer, plot_id, level, metric, class, id)), ]
-}
-
-#' @name sample_lsm
-#' @export
-sample_lsm.RasterStack <- function(landscape,
-                                   y,
-                                   plot_id = NULL,
-                                   shape = "square", size,
-                                   all_classes = FALSE,
-                                   return_raster = FALSE,
-                                   verbose = TRUE,
-                                   progress = FALSE,
-                                   ...) {
-
-    landscape <- raster::as.list(landscape)
-
-    result <- lapply(X = seq_along(landscape), FUN = function(x) {
-
-        if (progress) {
-
-            cat("\r> Progress nlayers: ", x , "/", length(landscape))
-        }
-
-        sample_lsm_int(landscape = landscape[[x]],
-                       y = y,
-                       plot_id = plot_id,
-                       shape = shape,
-                       size = size,
-                       all_classes = all_classes,
-                       verbose = verbose,
-                       progress = FALSE,
-                       ...)
-    })
-
-    layer <- rep(seq_along(result),
-                 vapply(result, nrow, FUN.VALUE = integer(1)))
-
-    result <- do.call(rbind, result)
-
-    result$layer <- layer
-
-    if (!return_raster) {
-        result  <- result[, -9]
-    }
-
-    if (progress) {cat("\n")}
-
-    result[with(result, order(layer, plot_id, level, metric, class, id)), ]
-}
-
-#' @name sample_lsm
-#' @export
-sample_lsm.RasterBrick <- function(landscape,
-                                   y,
-                                   plot_id = NULL,
-                                   shape = "square", size,
-                                   all_classes = FALSE,
-                                   return_raster = FALSE,
-                                   verbose = TRUE,
-                                   progress = FALSE,
-                                   ...) {
-
-    landscape <- raster::as.list(landscape)
-
-    result <- lapply(X = seq_along(landscape), FUN = function(x) {
-
-        if (progress) {
-
-            cat("\r> Progress nlayers: ", x , "/", length(landscape))
-        }
-
-        sample_lsm_int(landscape = landscape[[x]],
-                       y = y,
-                       plot_id = plot_id,
-                       shape = shape,
-                       size = size,
-                       all_classes = all_classes,
-                       verbose = verbose,
-                       progress = FALSE,
-                       ...)
-    })
-
-    layer <- rep(seq_along(result),
-                 vapply(result, nrow, FUN.VALUE = integer(1)))
-
-    result <- do.call(rbind, result)
-
-    result$layer <- layer
-
-    if (!return_raster) {
-        result  <- result[, -9]
-    }
-
-    if (progress) {cat("\n")}
-
-    result[with(result, order(layer, plot_id, level, metric, class, id)), ]
-}
-
-#' @name sample_lsm
-#' @export
-sample_lsm.stars <- function(landscape,
-                             y,
-                             plot_id = NULL,
-                             shape = "square", size,
-                             all_classes = FALSE,
-                             return_raster = FALSE,
-                             verbose = TRUE,
-                             progress = FALSE,
-                             ...) {
-
-    landscape <-  raster::as.list(methods::as(landscape, "Raster"))
-
-    result <- lapply(X = seq_along(landscape), FUN = function(x) {
-
-        if (progress) {
-
-            cat("\r> Progress nlayers: ", x , "/", length(landscape))
-        }
-
-        sample_lsm_int(landscape = landscape[[x]],
-                       y = y,
-                       plot_id = plot_id,
-                       shape = shape,
-                       size = size,
-                       all_classes = all_classes,
-                       verbose = verbose,
-                       progress = FALSE,
-                       ...)
-    })
-
-    layer <- rep(seq_along(result),
-                 vapply(result, nrow, FUN.VALUE = integer(1)))
-
-    result <- do.call(rbind, result)
-
-    result$layer <- layer
-
-    if (!return_raster) {
-        result  <- result[, -9]
-    }
-
-    if (progress) {cat("\n")}
-
-    result[with(result, order(layer, plot_id, level, metric, class, id)), ]
-}
-
-#' @name sample_lsm
-#' @export
-sample_lsm.list <- function(landscape,
                             y,
                             plot_id = NULL,
                             shape = "square", size,
@@ -278,6 +86,8 @@ sample_lsm.list <- function(landscape,
                             progress = FALSE,
                             ...) {
 
+    landscape <- landscape_as_list(landscape)
+
     result <- lapply(X = seq_along(landscape), FUN = function(x) {
 
         if (progress) {
