@@ -34,124 +34,29 @@
 #'
 #' @export
 show_cores <- function(landscape,
-                       directions,
-                       class,
-                       labels,
-                       nrow,
-                       ncol,
-                       consider_boundary,
-                       edge_depth) UseMethod("show_cores")
+                       directions = 8,
+                       class = "all",
+                       labels = FALSE,
+                       nrow = NULL,
+                       ncol = NULL,
+                       consider_boundary = TRUE,
+                       edge_depth = 1) {
 
+    landscape <- landscape_as_list(landscape)
 
-#' @name show_cores
-#' @export
-show_cores.RasterLayer <- function(landscape,
-                                   directions = 8,
-                                   class = "all",
-                                   labels = FALSE,
-                                   nrow = NULL,
-                                   ncol = NULL,
-                                   consider_boundary = FALSE,
-                                   edge_depth = 1) {
+    result <- lapply(X = landscape,
+                     FUN = show_cores_internal,
+                     directions = directions,
+                     class = class,
+                     labels = labels,
+                     nrow = nrow,
+                     ncol = ncol,
+                     consider_boundary = consider_boundary,
+                     edge_depth = edge_depth)
 
-    show_cores_internal(landscape,
-                        directions = directions,
-                        class = class,
-                        labels = labels,
-                        nrow = nrow,
-                        ncol = ncol,
-                        consider_boundary = consider_boundary,
-                        edge_depth = edge_depth)
-}
+    names(result) <- paste0("layer_", 1:length(result))
 
-#' @name show_cores
-#' @export
-show_cores.RasterStack <- function(landscape,
-                                   directions = 8,
-                                   class = "all",
-                                   labels = FALSE,
-                                   nrow = NULL,
-                                   ncol = NULL,
-                                   consider_boundary = FALSE,
-                                   edge_depth = 1) {
-
-    lapply(X = raster::as.list(landscape),
-           FUN = show_cores_internal,
-           directions = directions,
-           class = class,
-           labels = labels,
-           nrow = nrow,
-           ncol = ncol,
-           consider_boundary = consider_boundary,
-           edge_depth = edge_depth)
-}
-
-#' @name show_cores
-#' @export
-show_cores.RasterBrick <- function(landscape,
-                                   directions = 8,
-                                   class = "all",
-                                   labels = FALSE,
-                                   nrow = NULL,
-                                   ncol = NULL,
-                                   consider_boundary = FALSE,
-                                   edge_depth = 1) {
-
-    lapply(X = raster::as.list(landscape),
-           FUN = show_cores_internal,
-           directions = directions,
-           class = class,
-           labels = labels,
-           nrow = nrow,
-           ncol = ncol,
-           consider_boundary = consider_boundary,
-           edge_depth = edge_depth)
-}
-
-#' @name show_cores
-#' @export
-show_cores.stars <- function(landscape,
-                             directions = 8,
-                             class = "all",
-                             labels = FALSE,
-                             nrow = NULL,
-                             ncol = NULL,
-                             consider_boundary = FALSE,
-                             edge_depth = 1) {
-
-    landscape <- methods::as(landscape, "Raster")
-
-    lapply(X = raster::as.list(landscape),
-           FUN = show_cores_internal,
-           directions = directions,
-           class = class,
-           labels = labels,
-           nrow = nrow,
-           ncol = ncol,
-           consider_boundary = consider_boundary,
-           edge_depth = edge_depth)
-}
-
-#' @name show_cores
-#' @export
-show_cores.list <- function(landscape,
-                            directions = 8,
-                            class = "all",
-                            labels = FALSE,
-                            nrow = NULL,
-                            ncol = NULL,
-                            consider_boundary = FALSE,
-                            edge_depth = 1) {
-
-    lapply(X = landscape,
-           FUN = show_cores_internal,
-           directions = directions,
-           class = class,
-           labels = labels,
-           nrow = nrow,
-           ncol = ncol,
-           consider_boundary = consider_boundary,
-           edge_depth = edge_depth)
+    return(result)
 }
 
 show_cores_internal <- function(landscape, directions, class, labels, nrow, ncol,
@@ -176,11 +81,12 @@ show_cores_internal <- function(landscape, directions, class, labels, nrow, ncol
                                               resolution = resolution_xy,
                                               crs = raster::crs(landscape))
 
-    landscape_labeled <- get_patches(landscape, directions = directions)
+    landscape_labeled <- get_patches(landscape, directions = directions)[[1]]
 
     for (i in seq_len(length(landscape_labeled) - 1)) {
 
-        max(rcpp_get_unique_values(raster::as.matrix(landscape_labeled[[i]])))
+        max(get_unique_values_int(raster::as.matrix(landscape_labeled[[i]]),
+                                  verbose = FALSE))
 
         max_patch_id <- max(raster::values(landscape_labeled[[i]]), na.rm = TRUE)
 
@@ -270,7 +176,7 @@ show_cores_internal <- function(landscape, directions, class, labels, nrow, ncol
                                    na.value = "grey85") +
         ggplot2::scale_x_continuous(expand = c(0, 0)) +
         ggplot2::scale_y_continuous(expand = c(0, 0)) +
-        ggplot2::guides(fill = FALSE) +
+        ggplot2::guides(fill = "none") +
         ggplot2::labs(titel = NULL, x = NULL, y = NULL) +
         ggplot2::theme(
             axis.title  = ggplot2::element_blank(),
